@@ -12,11 +12,7 @@ from .gather_and_scatter_mixin import GatherAndScatterMixin
 class Gather(GatherAndScatterMixin, BackendHandler):
 
   @classmethod
-  def version_1(cls, node, **kwargs):
-    return [cls.make_tensor_from_onnx_node(node, **kwargs)]
-
-  @classmethod
-  def version_11(cls, node, **kwargs):
+  def _common(cls, node, **kwargs):
     x = kwargs["tensor_dict"][node.inputs[0]]
     indices = kwargs["tensor_dict"][node.inputs[1]]
     attrs = copy.deepcopy(node.attrs)
@@ -27,3 +23,15 @@ class Gather(GatherAndScatterMixin, BackendHandler):
       indices = cls.process_neg_idx_along_axis(x, axis, indices)
       attrs['axis'] = axis
       return [cls.make_tensor_from_onnx_node(node, attrs=attrs, inputs=[x, indices], **kwargs)]
+
+  @classmethod
+  def version_1(cls, node, **kwargs):
+    return [cls.make_tensor_from_onnx_node(node, **kwargs)]
+
+  @classmethod
+  def version_11(cls, node, **kwargs):
+    return cls._common(node, **kwargs)
+
+  @classmethod
+  def version_13(cls, node, **kwargs):
+    return cls._common(node, **kwargs)
