@@ -1,10 +1,10 @@
 backend_opset_version = {
-    'Abs': [1, 6],
+    'Abs': [1, 6, 13],
     'Acos': [7],
     'Acosh': [9],
     'Adagrad': [],
     'Adam': [],
-    'Add': [1, 6, 7, 13],
+    'Add': [1, 6, 7, 13, 14],
     'And': [1, 7],
     'ArgMax': [1, 11, 12, 13],
     'ArgMin': [1, 11, 12, 13],
@@ -14,10 +14,12 @@ backend_opset_version = {
     'Atan': [7],
     'Atanh': [9],
     'AveragePool': [1, 7, 10, 11],
-    'BatchNormalization': [1, 6, 7, 9],
+    'BatchNormalization': [1, 6, 7, 9, 14],
+    'Bernoulli': [],
     'Binarizer': [],
     'BitShift': [11],
     'Cast': [1, 6, 9, 13],
+    'CastLike': [],
     'CastMap': [],
     'CategoryMapper': [],
     'Ceil': [1, 6, 13],
@@ -34,12 +36,12 @@ backend_opset_version = {
     'ConvTranspose': [1, 11],
     'Cos': [7],
     'Cosh': [9],
-    'CumSum': [11],
-    'DepthToSpace': [1, 11],
-    'DequantizeLinear': [10],
+    'CumSum': [11, 14],
+    'DepthToSpace': [1, 11, 13],
+    'DequantizeLinear': [10, 13],
     'Det': [11],
     'DictVectorizer': [],
-    'Div': [1, 6, 7],
+    'Div': [1, 6, 7, 13, 14],
     'Dropout': [1, 6, 7, 10, 12, 13],
     'DynamicQuantizeLinear': [11],
     'Einsum': [12],
@@ -47,16 +49,16 @@ backend_opset_version = {
     'Equal': [1, 7, 11, 13],
     'Erf': [9, 13],
     'Exp': [1, 6, 13],
-    'Expand': [8],
+    'Expand': [8, 13],
     'EyeLike': [9],
     'FeatureVectorizer': [],
-    'Flatten': [1, 9, 11],
+    'Flatten': [1, 9, 11, 13],
     'Floor': [1, 6, 13],
-    'GRU': [1, 3, 7],
-    'Gather': [1, 11],
+    'GRU': [1, 3, 7, 14],
+    'Gather': [1, 11, 13],
     'GatherElements': [11, 13],
     'GatherND': [11, 12, 13],
-    'Gemm': [1, 6, 7, 9, 11],
+    'Gemm': [1, 6, 7, 9, 11, 13],
     'GlobalAveragePool': [1],
     'GlobalLpPool': [1, 2],
     'GlobalMaxPool': [1],
@@ -64,8 +66,9 @@ backend_opset_version = {
     'Greater': [1, 7, 9, 13],
     'GreaterOrEqual': [12],
     'HardSigmoid': [1, 6],
+    'HardSwish': [14],
     'Hardmax': [1, 11, 13],
-    'Identity': [1, 13],
+    'Identity': [1, 13, 14],
     'If': [1, 11, 13],
     'ImageScaler': [1],
     'Imputer': [],
@@ -73,7 +76,7 @@ backend_opset_version = {
     'IsInf': [10],
     'IsNaN': [9, 13],
     'LRN': [1, 13],
-    'LSTM': [1, 7],
+    'LSTM': [1, 7, 14],
     'LabelEncoder': [],
     'LeakyRelu': [1, 6],
     'Less': [1, 7, 9, 13],
@@ -81,7 +84,7 @@ backend_opset_version = {
     'LinearClassifier': [],
     'LinearRegressor': [],
     'Log': [1, 6, 13],
-    'LogSoftmax': [1, 11],
+    'LogSoftmax': [1, 11, 13],
     'Loop': [1, 11, 13],
     'LpNormalization': [1],
     'LpPool': [1, 2, 11],
@@ -91,47 +94,50 @@ backend_opset_version = {
     'MaxPool': [1, 8, 10, 11, 12],
     'MaxRoiPool': [],
     'MaxUnpool': [9, 11],
-    'Mean': [1, 6, 8],
-    'MeanVarianceNormalization': [1, 9],
+    'Mean': [1, 6, 8, 13],
+    'MeanVarianceNormalization': [1, 9, 13],
     'Min': [1, 6, 8, 12, 13],
     'Mod': [10, 13],
     'Momentum': [],
-    'Mul': [1, 6, 7, 13],
-    'Multinomial': [],
+    'Mul': [1, 6, 7, 13, 14],
+    'Multinomial': [7],
     'Neg': [1, 6, 13],
     'NegativeLogLikelihoodLoss': [],
     'NonMaxSuppression': [10, 11],
-    'NonZero': [9],
+    'NonZero': [9, 13],
     'Normalizer': [],
     'Not': [1],
     'OneHot': [9, 11],
     'OneHotEncoder': [],
+    'Optional': [],
+    'OptionalGetElement': [],
+    'OptionalHasElement': [],
     'Or': [1, 7],
     'PRelu': [1, 6, 7, 9],
-    'Pad': [1, 2, 11],
+    'Pad': [1, 2, 11, 13],
     'Pow': [1, 7, 12, 13],
     'QLinearConv': [10],
     'QLinearMatMul': [10],
-    'QuantizeLinear': [10],
-    'RNN': [1, 7],
+    'QuantizeLinear': [10, 13],
+    'RNN': [1, 7, 14],
     'RandomNormal': [1],
     'RandomNormalLike': [1],
     'RandomUniform': [1],
     'RandomUniformLike': [1],
     'Range': [11],
-    'Reciprocal': [1, 6],
-    'ReduceL1': [1, 11],
-    'ReduceL2': [1, 11],
-    'ReduceLogSum': [1, 11],
-    'ReduceLogSumExp': [1, 11],
+    'Reciprocal': [1, 6, 13],
+    'ReduceL1': [1, 11, 13],
+    'ReduceL2': [1, 11, 13],
+    'ReduceLogSum': [1, 11, 13],
+    'ReduceLogSumExp': [1, 11, 13],
     'ReduceMax': [1, 11, 12, 13],
     'ReduceMean': [1, 11, 13],
     'ReduceMin': [1, 11, 12, 13],
     'ReduceProd': [1, 11, 13],
-    'ReduceSum': [1, 11],
-    'ReduceSumSquare': [1, 11],
-    'Relu': [1, 6, 13],
-    'Reshape': [1, 5],
+    'ReduceSum': [1, 11, 13],
+    'ReduceSumSquare': [1, 11, 13],
+    'Relu': [1, 6, 13, 14],
+    'Reshape': [1, 5, 13, 14],
     'Resize': [10, 11, 13],
     'ReverseSequence': [10],
     'RoiAlign': [10],
@@ -142,7 +148,7 @@ backend_opset_version = {
     'Scan': [8, 9, 11],
     'Scatter': [9],
     'ScatterElements': [11, 13],
-    'ScatterND': [11],
+    'ScatterND': [11, 13],
     'Selu': [1, 6],
     'SequenceAt': [11],
     'SequenceConstruct': [11],
@@ -150,35 +156,36 @@ backend_opset_version = {
     'SequenceErase': [11],
     'SequenceInsert': [11],
     'SequenceLength': [11],
-    'Shape': [1],
+    'Shape': [1, 13],
     'Shrink': [9],
-    'Sigmoid': [1, 6],
+    'Sigmoid': [1, 6, 13],
     'Sign': [9, 13],
     'Sin': [7],
     'Sinh': [9],
-    'Size': [1],
+    'Size': [1, 13],
     'Slice': [1, 10, 11, 13],
-    'Softmax': [1, 11],
+    'Softmax': [1, 11, 13],
     'SoftmaxCrossEntropyLoss': [],
     'Softplus': [1],
     'Softsign': [1],
-    'SpaceToDepth': [1],
+    'SpaceToDepth': [1, 13],
     'Split': [1, 2, 11, 13],
     'SplitToSequence': [11],
     'Sqrt': [1, 6, 13],
     'Squeeze': [1, 11],
     'StringNormalizer': [],
-    'Sub': [1, 6, 7, 13],
-    'Sum': [1, 6, 8],
+    'Sub': [1, 6, 7, 13, 14],
+    'Sum': [1, 6, 8, 13],
     'Tan': [7],
     'Tanh': [1, 6, 13],
     'TfIdfVectorizer': [9],
     'ThresholdedRelu': [1, 10],
-    'Tile': [1, 6],
+    'Tile': [1, 6, 13],
     'TopK': [1, 10, 11],
-    'Transpose': [1],
+    'Transpose': [1, 13],
     'TreeEnsembleClassifier': [],
     'TreeEnsembleRegressor': [],
+    'Trilu': [14],
     'Unique': [],
     'Unsqueeze': [1, 11],
     'Upsample': [7, 9],
@@ -188,6 +195,8 @@ backend_opset_version = {
 }
 
 backend_partial_support = {
+    'BatchNormalization': 'BatchNormalization with training_mode=1 is not '
+                          'supported in Tensorflow converte.',
     'Cast': 'Cast string to data types other than float32/float64/int32/int64 '
             'is not supported in Tensorflow',
     'ConcatFromSequence': 'new_axis=1 not supported in Tensorflow.',
