@@ -86,9 +86,6 @@ backend_test.exclude(r'test_loop13_seq[a-z,_]*')
 backend_test.exclude(r'test_min_uint64_[a-z,_]*')
 backend_test.exclude(r'test_max_uint64_[a-z,_]*')
 
-# TF one_hot do not support float32 for depth when auto-cast is False (default)
-backend_test.exclude(r'test_onehot_[a-z,_]*')
-
 if legacy_opset_pre_ver(7):
   backend_test.exclude(r'[a-z,_]*Upsample[a-z,_]*')
 
@@ -143,6 +140,26 @@ backend_test.exclude(r'test_lstm_[a-z,_]*')
 backend_test.exclude(r'test_rnn_[a-z,_]*')
 backend_test.exclude(r'test_simple_rnn_[a-z,_]*')
 
+# TF doesn't support auto_pad=SAME_LOWER for Conv and ConvTranspose
+backend_test.exclude(r'test_conv_with_autopad_same_[a-z,_]*')
+backend_test.exclude(r'test_convtranspose_autopad_same_[a-z,_]*')
+
+# Exclude non-deterministic tests
+backend_test.exclude(r'test_bernoulli_expanded[a-z,_]*')
+backend_test.exclude(r'test_bernoulli_double_expanded[a-z,_]*')
+backend_test.exclude(r'test_bernoulli_seed_expanded[a-z,_]*')
+
+# Exclude optional_get_element, test_optional_has_element tests
+backend_test.exclude(r'test_optional_get_element[a-z,_]*')
+backend_test.exclude(r'test_optional_has_element[a-z,_]*')
+
+# Exclude BatchNormalization with training_mode=1 tests
+backend_test.exclude(r'test_batchnorm_epsilon_training_mode[a-z,_]*')
+backend_test.exclude(r'test_batchnorm_example_training_mode[a-z,_]*')
+
+# ONNX 1.9.0 test case does not support sequence
+backend_test.exclude(r'[a-z,_]*identity_sequence_[a-z,_]*')
+
 # import all test cases at global scope to make them visible to python.unittest
 globals().update(backend_test.enable_report().test_cases)
 
